@@ -3,4 +3,6 @@
 # Copyright (c) CERN, 2021.                 #
 # ######################################### #
 
-from .particles import *
+from .particles import Particles
+from .particles_purely_longitudinal import ParticlesPurelyLongitudinal
+from .particles_base import *
